==> breeze_website_builder_5.4.44.tar.gz: manage/delete_page.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Revised: 10/12/2010	ELL
// Changed timestamping of `revised` field due to change from VARCHAR to DATETIME in table structure.
// Revised: 1/13/2012	ELL
// Added deletion of draft copies as well.
// Revised: 2/8/2012	ELL
// Added table prefix handling. Added reference to user files folder constant.
// Revised: 11/20/2014	ELL
// Added "redirect", "folder" and separated "page_name" from "file_name" such that this module can be used in more than one place.
//
	include ("check_session.php");

	$page_name = $_GET['page_name'];
	$file_name = $_GET['file_name'];
	$folder = $_GET['folder'];
	$redirect = $_GET['redirect'];
	
	if ($folder == "pages")
	{
		// Before we go any farther, back this puppy up!
		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "page_data WHERE page_name='$page_name'";
		$result = $bwb_dbh->query($query);
		$row = $result->fetch(PDO::FETCH_ASSOC);
		$page_content = $row["page_content"];
		$revised = $row["revised"];
		$today = date("Y-m-d H:i:s");
		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_bkup SET page_name='$page_name', page_content='$page_content', revised='$revised', deleted='$today'";
		$cnt = $bwb_dbh->exec($query);
		
		// Now go ahead and delete page record from table.
		$query = "DELETE FROM " . BWB_TABLE_PREFIX . "page_data WHERE page_name = '$page_name'";
		$cnt = $bwb_dbh->exec($query);
		// And remove draft while you are at it.
		$query = "DELETE FROM " . BWB_TABLE_PREFIX . "page_data_draft WHERE page_name = '$page_name' AND `source`=0";
		$cnt = $bwb_dbh->exec($query);
	}
	
	// And delete actual page.
	$document_root = $_SERVER['DOCUMENT_ROOT'];
	if ($folder == "pages")
	{
		if ((BWB_BASE_DIR == '') && (BWB_WEBPAGE_DIR == ''))
			$path = $document_root . "/" . $file_name;
		elseif (BWB_BASE_DIR == '')
			$path = $document_root . "/" . BWB_WEBPAGE_DIR . "/" . $file_name;
		else
			$path = $document_root . "/" . BWB_BASE_DIR . "/" . BWB_WEBPAGE_DIR . "/" . $file_name;
	}
	elseif ($folder == "scripts")
	{
		if (BWB_BASE_DIR == '')
			$path = $document_root . "/" . BWB_SCRIPTS_DIR . "/" . $file_name;
		else
			$path = $document_root . "/" . BWB_BASE_DIR . "/" . BWB_SCRIPTS_DIR . "/" . $file_name;
	}
	elseif ($folder == "php")
		$path = $document_root . "/php/" . $file_name;
	else
	{
		echo "Error: no folder specified";
		exit;
	}
	
	if (file_exists($path))
	{
		// Delete file.
		$fh = fopen($path, 'w') or die("Can't open $path: $php_errormsg");
		fclose($fh) or die($php_errormsg);
		unlink($path);
	}
	
	header("Location: $redirect");
	
?>

==> breeze_website_builder_5.4.54.tar.gz: manage/delete_page.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Revised: 10/12/2010	ELL
// Changed timestamping of `revised` field due to change from VARCHAR to DATETIME in table structure.
// Revised: 1/13/2012	ELL
// Added deletion of draft copies as well.
// Revised: 2/8/2012	ELL
// Added table prefix handling. Added reference to user files folder constant.
// Revised: 11/20/2014	ELL
// Added "redirect", "folder" and separated "page_name" from "file_name" such that this module can be used in more than one place.
//
	include ("check_session.php");

	$page_name = $_GET['page_name'];
	$file_name = $_GET['file_name'];
	$folder = $_GET['folder'];
	$redirect = $_GET['redirect'];
	
	if ($folder == "pages")
	{
		// Before we go any farther, back this puppy up!
		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "page_data WHERE page_name='$page_name'";
		$result = $bwb_dbh->query($query);
		$row = $result->fetch(PDO::FETCH_ASSOC);
		$page_content = addslashes(stripslashes($row["page_content"]));
		$revised = $row["revised"];
		$today = date("Y-m-d H:i:s");
		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_bkup SET page_name='$page_name', page_content='$page_content', revised='$revised', deleted='$today'";
		$cnt = $bwb_dbh->exec($query);
		
		// Now go ahead and delete page record from table.
		$query = "DELETE FROM " . BWB_TABLE_PREFIX . "page_data WHERE page_name = '$page_name'";
		$cnt = $bwb_dbh->exec($query);
		// And remove draft while you are at it.
		$query = "DELETE FROM " . BWB_TABLE_PREFIX . "page_data_draft WHERE page_name = '$page_name' AND `source`=0";
		$cnt = $bwb_dbh->exec($query);
	}
	
	// And delete actual page.
	$document_root = $_SERVER['DOCUMENT_ROOT'];
	if ($folder == "pages")
	{
		if ((BWB_BASE_DIR == '') && (BWB_WEBPAGE_DIR == ''))
			$path = $document_root . "/" . $file_name;
		elseif (BWB_BASE_DIR == '')
			$path = $document_root . "/" . BWB_WEBPAGE_DIR . "/" . $file_name;
		else
			$path = $document_root . "/" . BWB_BASE_DIR . "/" . BWB_WEBPAGE_DIR . "/" . $file_name;
	}
	elseif ($folder == "scripts")
	{
		if (BWB_BASE_DIR == '')
			$path = $document_root . "/" . BWB_SCRIPTS_DIR . "/" . $file_name;
		else
			$path = $document_root . "/" . BWB_BASE_DIR . "/" . BWB_SCRIPTS_DIR . "/" . $file_name;
	}
	elseif ($folder == "php")
		$path = $document_root . "/php/" . $file_name;
	else
	{
		echo "Error: no folder specified";
		exit;
	}
	
	if (file_exists($path))
	{
		// Delete file.
		$fh = fopen($path, 'w') or die("Can't open $path: $php_errormsg");
		fclose($fh) or die($php_errormsg);
		unlink($path);
	}
	
	header("Location: $redirect");
	
?>
